import { FC, createElement as h } from 'react';
import { PageProps } from '@not-govuk/app-composer';

export const LoadingPage: FC<PageProps> = () => (
  <h1>Loading...</h1>
);

export default LoadingPage;
